@@ -124,6 +124,7 @@ def odbc_connection_function(
 def databricks_connection_function(host: str, http_path: str, token: str, database: str, schema: str, **kwargs):
     from databricks import sql
 
+    logging.getLogger("databricks.sql").setLevel(logging.INFO)
     connection = sql.connect(
         server_hostname=host, catalog=database, schema=schema, http_path=http_path, access_token=token
     )
@@ -190,7 +191,12 @@ class SparkSQLBase(DataSource):
         )
         query.execute()
         if len(query.rows) > 0:
-            columns = {row[0]: row[1] for row in query.rows}
+            rows = query.rows
+            # Remove the partitioning information (see https://spark.apache.org/docs/latest/sql-ref-syntax-aux-describe-table.html)
+            partition_indices = [i for i in range(len(rows)) if rows[i][0].startswith("# Partition")]
+            if partition_indices:
+                rows = rows[: partition_indices[0]]
+            columns = {row[0]: row[1] for row in rows}
 
             if included_columns or excluded_columns:
                 column_names = list(columns.keys())
@@ -222,7 +228,7 @@ class SparkSQLBase(DataSource):
         table_column_name: str = "table_name",
         schema_column_name: str = "table_schema",
     ) -> str:
-        from_clause = f" FROM {self.database}" if self.database else ""
+        from_clause = f" FROM {self.schema}" if self.schema else ""
         return f"SHOW TABLES{from_clause}"
 
     def sql_get_table_names_with_count(
